@@ -68,6 +68,24 @@ impl Parallel for InlineGlobals {
 impl VisitMut for InlineGlobals {
     noop_visit_mut_type!();
 
+    fn visit_mut_assign_expr(&mut self, n: &mut AssignExpr) {
+        n.right.visit_mut_with(self);
+
+        match &mut n.left {
+            PatOrExpr::Expr(l) => {
+                (&mut **l).visit_mut_children_with(self);
+            }
+            PatOrExpr::Pat(l) => match &mut **l {
+                Pat::Expr(l) => {
+                    (&mut **l).visit_mut_children_with(self);
+                }
+                _ => {
+                    l.visit_mut_with(self);
+                }
+            },
+        }
+    }
+
     fn visit_mut_expr(&mut self, expr: &mut Expr) {
         match expr {
             Expr::Ident(Ident { ref sym, span, .. }) => {
@@ -336,4 +354,16 @@ mod tests {
         "const test = process.env['x']",
         "const test = 'FOO'"
     );
+
+    test!(
+        Default::default(),
+        |tester| inline_globals(
+            envs(tester, &[("x", "BAR")]),
+            globals(tester, &[]),
+            Default::default(),
+        ),
+        issue_2499_1,
+        "process.env.x = 'foo'",
+        "process.env.x = 'foo'"
+    );
 }
