@@ -1,5 +1,7 @@
 pub use self::{
-    const_modules::const_modules, inline_globals::inline_globals, json_parse::json_parse,
+    const_modules::const_modules,
+    inline_globals::{inline_globals, inline_globals2, GlobalExprMap},
+    json_parse::json_parse,
     simplify::simplifier,
 };
 
